@@ -7,14 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QObject/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-
 
 1;
 
@@ -27,6 +25,13 @@ Qt::WebKit::QWebPluginFactory
 =over
 
 
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+
 =back
 
 =head2 EXPORT
